#include "lzr.h"
#include "cfg.h"
#include "intro.h"
#include "musi.h"
#include <stdlib.h>
#include <stdio.h>

static int init(void);
static void deinit(void);

static int state = 0;

int main(int argc, char **argv)
{
	(void)argc, (void)argv;
	if (init())
		return deinit(), fputs("init failed\n", stderr), 1;
	while (!LZR_ShouldQuit() && state < 2) {
		LZR_CycleEvents();
		switch (state) {
		case 0:
			if (intro_update())
				state += 1;
			break;
		case 1:
			if (musi_update())
				state += 1;
			break;
		default:
			break;
		}
		LZR_DrawBegin();
		if (state == 0)
			intro_draw();
		else
			musi_draw();
		LZR_DrawEnd();
	}
	return deinit(), 0;
}

static int init(void)
{
	if (LZR_Init(cfg))
		return 1;
	if (LZR_ImageLoad("res/handopen.bmp") < 0 ||
	    LZR_ImageLoad("res/handclose.bmp") < 0 ||
	    LZR_ImageLoad("res/stamp.bmp") < 0 ||
	    LZR_ImageLoad("res/bloody.bmp") < 0 ||
	    LZR_ImageLoad("res/bottomtext.bmp") < 0 ||
	    LZR_ImageLoad("res/toptext.bmp") < 0 ||
	    LZR_ImageLoad("res/wildass.bmp") < 0 ||
	    LZR_ImageLoad("res/inspi0.bmp") < 0 ||
	    LZR_ImageLoad("res/inspi1.bmp") < 0 ||
	    LZR_ImageLoad("res/inspi2.bmp") < 0 ||
	    LZR_ImageLoad("res/inspi3.bmp") < 0)
		return 1;
	intro_init();
	musi_init();
	return 0;
}

static void deinit(void)
{
	LZR_Quit();
}
